<?php
# -------------------------------------------------------
# Conference Management Tool
# -------------------------------------------------------
# (c) 2003 by VSIS, Hamburg University, Germany
# -------------------------------------------------------
# 
# This file loads configuration and contains some 
# bootstrapping code for loading further classes and
# functions from other files. 
#

require('conftool.conf');

# returns a path from configuration. Relative paths are prepended
# by the prefix.
function ct_get_path($idx) {
	global $ctconf;

	return (substr($ctconf['paths/'.$idx], 0, 1) == '/') ? 
					$ctconf['paths/'.$idx] :
					$ctconf['paths/prefix'] . $ctconf['paths/'.$idx];
}

# load a library
function ct_load_lib($lib) {
	global $ctconf;	

	$libpath = ct_get_path('lib');
	include_once($libpath.$lib);
}

# load a class definition.
function ct_load_class($class) {
	global $ctconf;	

	$libpath = ct_get_path('lib');
	include_once($libpath.$class.'.ctcls');
}

# load a page definition
function ct_load_page($page) {
	global $ctconf, $http, $session, $db, $HTTP_SERVER_VARS, $HTTP_POST_FILES, $user;

	$user =& $session->get_user();
	$libpath = ct_get_path('pages');
    #   set_error_handler("ct_error_handler");

	# check if file exists
	if (!file_exists($libpath.$page.'.page')) {
		$session->put_errorbox(S_ERROR_SYSTEM, S_ERROR_SYSTEM_FILENOTFOUND);
		ct_redirect(ct_pageurl('error'));
	}
	include_once($libpath.$page.'.page');
    #   restore_error_handler();
}

#  conftool error handler.
function ct_error_handler ($errno, $errstr, $errfile, $errline, $errcontext) 
{
    #echo "<H3>Error! Please contact harald@weinreichs.de!</H3>";    
    echo "<B>Debugging Information</B><BR>";    
    echo "Error ".$errno.": ".$errstr."<BR>";
    echo "Context: ".$errcontext."<BR>";  
    echo "File: ".$errfile."<BR>";
    echo "Line: ".$errline."<BR><BR>";
}

# load base classes and database adapter
function ct_base_classes() {
	global $ctconf;

	ct_load_class('CTSession');
	ct_load_class('CTPerson');
	ct_load_class('CTPaper');
	ct_load_class('CTParticipation');
	ct_load_class('CTForm');
	ct_load_class('CTReview');
	ct_load_lib($ctconf['db/dbms'].'.dbi');
	ct_load_lib('phases.lib');
	ct_load_lib('participation.lib');
}

# build a url that points to a ct page
function ct_pageurl($page,$getvars=array(), $pathinfo="", $id="conftool") {
	$url = ct_getbaseurl();
	$url .= "index.php".$pathinfo."?id=".$id."&page=".$page;
	while (list($k,$v) = each($getvars)) {
		$url .= "&".urlencode($k)."=".urlencode($v);
	}
	if (SID != "") {
		return $url."&".SID;   
	} else {
		return $url;   
	}
}

# get baseurl of conftool. this is either %ctconf['web/baseurl'] or if not set it will be extracted
# from the URL of the current document.
function ct_getbaseurl() {
	global $ctconf, $HTTP_SERVER_VARS;
	if (isset($ctconf['web/baseurl']) && $ctconf['web/baseurl'] != "" ) {
		$url = $ctconf['web/baseurl'];
	} else {
		if ($HTTP_SERVER_VARS['HTTPS'] == "on")
		   $protocol="https";
        else		   
		   $protocol="http";
		if (strpos($HTTP_SERVER_VARS['REQUEST_URI'],"index.php") === FALSE)
		   $path=$HTTP_SERVER_VARS['REQUEST_URI'];
		else
		   $path=substr($HTTP_SERVER_VARS['REQUEST_URI'],0,strpos($HTTP_SERVER_VARS['REQUEST_URI'],"index.php"));
			//	http://".$HTTP_SERVER_VARS['HTTP_HOST'].substr($HTTP_SERVER_VARS['REQUEST_URI'],0,70).
		$url = $protocol."://".$HTTP_SERVER_VARS['HTTP_HOST'].$path;
	}
	return $url;
}


# set navigation path to be displayed at foot of page.
function ct_pagepath($path) {
	global $pagepath;
	$pagepath = $path;
}

# redirect browser to another URL, script execution ends here!
function ct_redirect($url) {
#	header("HTTP/1.1 301 Moved Permanently");
#echo "<B>Debugging Information: redirect '".$url."'</B><BR>";    
	header("Location: ".$url);
#	header("Connection: close");
#	flush();
	exit();
}

# send a redirect response to browser to reload the current page
function ct_reload_page() {
	global $HTTP_SERVER_VARS;
	ct_redirect($HTTP_SERVER_VARS['REQUEST_URI']);
}


# FUNCTIONS THAT CHECK PERMISSIONS
# =====================================================================

# function ct_check_phases($phases) can be found in phases.lib


# check if the current user has administration rights...
function ct_requireadmin() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_admin()) {
		$session->put_errorbox(S_ERROR_ACCESSDENIED, S_ERROR_ACCESS_ADMINONLY);
		ct_redirect(ct_pageurl('error'));
	}
	ct_load_lib('admin.lib');
}

# Access only for conference PC Chair
function ct_requirechair() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_chair() && !$user->is_admin()) {
		$session->put_errorbox(S_ERROR_ACCESSDENIED, S_ERROR_ACCESS_ADMINONLY);
		ct_redirect(ct_pageurl('error'));
	}
	ct_load_lib('admin.lib');
}

# Access only for frontdesk people
function ct_requirefrontdesk() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_frontdesk() && !$user->is_admin()) {
		$session->put_errorbox(S_ERROR_ACCESSDENIED, S_ERROR_ACCESS_ADMINONLY);
		ct_redirect(ct_pageurl('error'));
	}
	ct_load_lib('admin.lib');
	ct_load_lib('frontdesk.lib');
}


# display error message
function ct_error_msg($msg) {
	echo "<span class=\"error_msg\">$msg</span><br>\n";
}

# display an errorbox on the current page
function ct_errorbox($title, $msg) {
	echo "<hr size=1 noshade>\n";
	echo "<table width=\"100%\" cellspacing=0 cellpadding=5 border=0 align=center>\n";
	echo "<tr><td class=\"errorboxTitleTD\" align=left colspan=3>\n";
	echo "<span class=\"errorboxTitle\">&nbsp;&nbsp;$title</span></td></tr>\n";
	echo "<tr>";
	echo "<td class=\"errorboxTitleTD\" align=left valign=top width=\"5%\">&nbsp;</td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"75%\">\n";
	echo "<span class=\"boxMsg\">$msg</span></td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"20%\">&nbsp;</td>\n";
	echo "</tr></table>\n";
}

# show an information box on the current page
function ct_infobox($title, $msg) {
	echo "<hr size=1 noshade>\n";
	echo "<table width=\"100%\" cellspacing=0 cellpadding=5 border=0 align=center>\n";
	echo "<tr><td class=\"infoboxTitleTD\" align=left colspan=3>\n";
	echo "<span class=\"infoboxTitle\">&nbsp;&nbsp;$title</span></td></tr>\n";
	echo "<tr>";
	echo "<td class=\"infoboxTitleTD\" align=left valign=top width=\"5%\">&nbsp;</td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"75%\">\n";
	echo "<span class=\"boxMsg\">$msg</span></td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"20%\">&nbsp;</td>\n";
	echo "</tr></table>\n";
}

# load language file
function ct_load_lang() {
	global $ctconf;
	
	#echo _get_path('etc').$ctconf['language'].".lang";

	$lang = fopen(ct_get_path('etc').$ctconf['language'].".lang", "r");
	while (!feof($lang)) {
		$line = trim(fgets($lang, 4096));
		if (($line != "") && !preg_match("/^#/", $line)) {
			$x = explode("=", $line, 2);
			define($x[0], $x[1]);
		}
	}	
}

# look if post parameter is present and has a certain parameter
function in_http($name, $value=false) {
	global $http;
	if (isset($http[$name])) {
		if (is_string($value)) {
			return ($value == $http[$name]);
		} else {
			return true;
		}
	} else {		
		return false;
	}
}

?>
