# Create and use database...
CREATE DATABASE IF NOT EXISTS ICA3PP;
USE ICA3PP;

# First drop old tables
DROP TABLE IF EXISTS contributiontypes;
DROP TABLE IF EXISTS emails2papers;
DROP TABLE IF EXISTS events;
DROP TABLE IF EXISTS eventtypes;
DROP TABLE IF EXISTS groups;
DROP TABLE IF EXISTS papers;
DROP TABLE IF EXISTS participants;
DROP TABLE IF EXISTS participants2events;
DROP TABLE IF EXISTS pc2papers;
DROP TABLE IF EXISTS pc2topics;
DROP TABLE IF EXISTS persons;
DROP TABLE IF EXISTS phases;
DROP TABLE IF EXISTS pricecategories;
DROP TABLE IF EXISTS prices;
DROP TABLE IF EXISTS reviews;
DROP TABLE IF EXISTS timediscounts;
DROP TABLE IF EXISTS topics;
DROP TABLE IF EXISTS topics2papers;
DROP TABLE IF EXISTS tracks;
DROP TABLE IF EXISTS tracks2topics;
DROP TABLE IF EXISTS vats;


#
# Table structure for table 'contributiontypes'
#

CREATE TABLE contributiontypes (
   ID int(11) NOT NULL auto_increment,
   title varchar(255) DEFAULT '""' NOT NULL,
   info varchar(255) DEFAULT '""',
   active enum('true','false') DEFAULT 'false' NOT NULL,
   PRIMARY KEY (id)
);

#
# Default data for table 'contributiontypes'
#

INSERT INTO contributiontypes VALUES( '1', 'Paper', 'Papers must be comprised of 10-13 pages', 'true');
INSERT INTO contributiontypes VALUES( '2', 'Short Paper', 'Short Papers are limited to 3-4 pages', 'true');
INSERT INTO contributiontypes VALUES( '3', 'Poster', 'A poster must be handed in with a one-page abstract.', 'false');



#
# Table structure for table 'emails2papers'
#

CREATE TABLE emails2papers (
  paperID int(11) NOT NULL,
  email varchar(255),
  PRIMARY KEY  (paperID)
);



#
# Default data for table 'emails2papers'
#


#
# Table structure for table 'events'
#

CREATE TABLE events (
  ID int(11) NOT NULL auto_increment,
  seqorder int(11) NOT NULL,
  title varchar(255),
  info varchar(255) NOT NULL,
  pricecategory int(11) NOT NULL,
  eventtype int(11) NOT NULL,
  vat int(11) NOT NULL,
  short varchar(255) NOT NULL,
  eventdate varchar(255) NOT NULL,
  eventlocation varchar(255) NOT NULL,
  minnumber tinyint(4) NOT NULL,
  maxnumber tinyint(4) NOT NULL,
  defaultnumber tinyint(4) NOT NULL,
  disable enum('true','false') NOT NULL default 'false',
  PRIMARY KEY  (ID),
  KEY eventorder (seqorder)
);



#
# Default data for table 'events'
#


#
# Table structure for table 'eventtypes'
#

CREATE TABLE eventtypes (
  ID int(4) NOT NULL auto_increment,
  seqorder int(11) NOT NULL,
  title varchar(255) NOT NULL,
  info varchar(255) NOT NULL,
  exclusive enum('true','false') NOT NULL default 'false',
  PRIMARY KEY  (ID),
  KEY eventtypeorder (seqorder)
);



#
# Default data for table 'eventtypes'
#
INSERT INTO eventtypes VALUES("1","10","Main event","","false");
INSERT INTO eventtypes VALUES("2","20","Tutorial","","false");
INSERT INTO eventtypes VALUES("3","30","Evening event","","false");
INSERT INTO eventtypes VALUES("4","40","Proceedings","","false");


#
# Table structure for table 'groups'
#

CREATE TABLE groups (
  ID int(11) NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  PRIMARY KEY  (ID)
);



#
# Default data for table 'groups'
#
INSERT INTO groups VALUES("1","Regular");
INSERT INTO groups VALUES("2","Student");
INSERT INTO groups VALUES("3","Regular / Member");
INSERT INTO groups VALUES("4","Student / Member");

#
# Table structure for table 'papers'
#

CREATE TABLE papers (
  ID int(11) NOT NULL auto_increment,
  personID int(11) NOT NULL,
  author varchar(255) NOT NULL,
  title varchar(255) NOT NULL,
  keywords varchar(255),
  abstract blob,
  externalremark blob,
  lastupload datetime,
  filename varchar(255),
  originalname varchar(255),
  contributiontypeID int(11),
  track tinyint(4),
  acceptstatus tinyint(4),
  withdrawn tinyint(3) unsigned,
  PRIMARY KEY  (ID),
  KEY personID (personID),
  KEY title (title),
  KEY author (author)
);



#
# Default data for table 'papers'
#


#
# Table structure for table 'participants'
#

CREATE TABLE participants (
  personID int(11) NOT NULL,
  regdate datetime,
  status int(11),
  memberID varchar(255),
  paymethod enum('transfer','cc','cash','free'),
  cctype varchar(255),
  ccnumber varchar(255),
  ccholder varchar(255),
  ccexpdate varchar(255),
  invoice enum('true','false') NOT NULL default 'false',
  invoicedate datetime,
  total float(10,2),
  payamount float(10,2),
  paydate datetime,
  externalremark blob,
  internalremark blob,
  frontdesk set('arrived','confirmed','onlist'),
  deleted tinyint(4),
  PRIMARY KEY  (personID)
);



#
# Default data for table 'participants'
#


#
# Table structure for table 'participants2events'
#

CREATE TABLE participants2events (
  personID int(11) NOT NULL,
  eventID int(11) NOT NULL,
  number tinyint(4),
  deleted tinyint(4),
  PRIMARY KEY  (eventID,personID)
);



#
# Default data for table 'participants2events'
#


#
# Table structure for table 'pc2papers'
#

CREATE TABLE pc2papers (
  personenID int(11) NOT NULL,
  paperID int(11) NOT NULL,
  reviewdone tinyint(4),
  PRIMARY KEY  (paperID,personenID)
);



#
# Default data for table 'pc2papers'
#


#
# Table structure for table 'pc2topics'
#

CREATE TABLE pc2topics (
  personID int(11) NOT NULL,
  topicID int(11) NOT NULL,
  PRIMARY KEY  (personID,topicID)
);



#
# Default data for table 'pc2topics'
#


#
# Table structure for table 'persons'
#

CREATE TABLE persons (
  ID int(11) NOT NULL auto_increment,
  username varchar(255) NOT NULL,
  name varchar(255) NOT NULL,
  firstname varchar(255),
  title varchar(255),
  gender tinyint(4),
  organisation varchar(255),
  addr1 varchar(255),
  addr2 varchar(255),
  zip varchar(255),
  city varchar(255),
  country varchar(255),
  email varchar(255) NOT NULL,
  phone varchar(255),
  fax varchar(255),
  password varchar(255),
  url varchar(255),
  internalremark blob,
  externalremark blob,
  creationdate datetime,
  status set('admin','author','pc','participant','frontdesk','chair','assistant'),
  deleted tinyint(4) NOT NULL,
  PRIMARY KEY  (ID),
  KEY username (username),
  KEY name (name),
  KEY email (email)
);



#
# Default data for table 'persons'
#
INSERT INTO persons VALUES("1","admin","Administrator","Conftool","","1","-","-","","-","-","-","conftool@vsys.informatik.uni-hamburg.de","","","admin","","","","2002-01-16 20:53:50","admin","0");


#
# Table structure for table 'phases'
#

CREATE TABLE phases (
  ID varchar(31) NOT NULL,
  title varchar(255),
  starts datetime NOT NULL default '1980-01-01 00:00:00',
  ends datetime default '2099-12-31 00:00:00',
  active tinyint(1) default '1',
  PRIMARY KEY  (ID),
  KEY starts (starts)
);



#
# Default data for table 'phases'
#
INSERT INTO phases VALUES("submission","Submission of papers","2000-01-01 00:00:00","2010-12-31 00:00:00","1");
INSERT INTO phases VALUES("reviewing","Reviewing of submitted papers","2000-01-01 00:00:00","2010-12-31 00:00:00","1");
INSERT INTO phases VALUES("reviewresults","Reviewing results, visible for authors","2000-01-01 00:00:00","2010-12-31 00:00:00","1");
INSERT INTO phases VALUES("finalupload","Final upload of accepted papers","2000-01-01 00:00:00","2010-12-31 00:00:00","0");
INSERT INTO phases VALUES("participation","Registration of conference participation","2000-01-01 00:00:00","2010-12-31 00:00:00","0");
INSERT INTO phases VALUES("conference","Conference","2000-01-01 00:00:00","2010-12-31 00:00:00","0");
INSERT INTO phases VALUES("userregistration","User Registration","2000-01-01 00:00:00","2010-12-31 00:00:00","1");


#
# Table structure for table 'pricecategories'
#

CREATE TABLE pricecategories (
  ID tinyint(4) NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  PRIMARY KEY  (ID)
);



#
# Default data for table 'pricecategories'
#
# Example: INSERT INTO pricecategories VALUES("1","Price category 1 (conference)");


#
# Table structure for table 'prices'
#

CREATE TABLE prices (
  ID int(11) NOT NULL auto_increment,
  groupID int(11) NOT NULL,
  timediscountID int(11) NOT NULL,
  pricecategoryID int(11) NOT NULL,
  gross float(10,2) NOT NULL default '0.00',
  PRIMARY KEY (ID)
);



#
# Default data for table 'prices'
#


#
# Table structure for table 'reviews'
#

CREATE TABLE reviews (
  paperID int(11) NOT NULL,
  personID int(11) NOT NULL,
  creationdate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  downloaddate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  evaluation tinyint(4),
  significance tinyint(4),
  originality tinyint(4),
  relevance tinyint(4),
  readability tinyint(4),
  overall tinyint(4),
  familiarity tinyint(4),
  summary blob,
  authorcomments blob,
  pccomments blob,
  PRIMARY KEY  (paperID, personID),
  KEY creationdate (creationdate)
);



#
# Default data for table 'reviews'
#


#
# Table structure for table 'timediscounts'
#

CREATE TABLE timediscounts (
  ID int(11) NOT NULL auto_increment,
  title varchar(255),
  effectivefrom datetime NOT NULL,
  effectiveuntil datetime,
  PRIMARY KEY  (ID),
  KEY effectivefrom (effectivefrom)
);



#
# Default data for table 'timediscounts'
#
INSERT INTO timediscounts VALUES("1","Early registrants","2000-01-01 00:00:00","2003-03-19 23:59:59");
INSERT INTO timediscounts VALUES("2","Late registrants","2003-03-20 00:00:00","2005-05-25 23:59:59");


#
# Table structure for table 'topics'
#

CREATE TABLE topics (
  ID int(11) NOT NULL auto_increment,
  title varchar(255),
  PRIMARY KEY  (ID)
);



#
# Default data for table 'topics'
#


#
# Table structure for table 'topics2papers'
#

CREATE TABLE topics2papers (
  paperID int(11) NOT NULL,
  topicID int(11) NOT NULL,
  PRIMARY KEY  (paperID,topicID)
);



#
# Default data for table 'topics2papers'
#


#
# Table structure for table 'tracks'
#

CREATE TABLE tracks (
  ID int(11) NOT NULL auto_increment,
  title varchar(255),
  shorttitle varchar(255),
  time varchar(255),
  PRIMARY KEY  (ID)
);



#
# Default data for table 'tracks'
#


#
# Table structure for table 'tracks2topics'
#

CREATE TABLE tracks2topics (
  trackID int(11) NOT NULL,
  topicID int(11) NOT NULL,
  PRIMARY KEY  (topicID,trackID)
);



#
# Default data for table 'tracks2topics'
#


#
# Table structure for table 'vats'
#

CREATE TABLE vats (
  ID int(11) NOT NULL auto_increment,
  percentage float(5,2) NOT NULL default '0.00',
  PRIMARY KEY  (ID)
);



#
# Default data for table 'vats'
#
INSERT INTO vats VALUES("1","0.00");
INSERT INTO vats VALUES("2","7.00");
INSERT INTO vats VALUES("3","16.00");
